      REAL FUNCTION SRSCF (RAD, TMIN, DD, LAI, SAI, R5, CVPD, RM,
     *                CR, GLMAX, GLMIN)
C     canopy surface resistance, RSC, s/m
C     after Shuttleworth and Gurney (1990) and Stewart (1988)
C     input
C        RS      solar radiation on canopy, W/m2
C        TMIN    minimum air temperature for the day, degC
C        DD      vapor pressure deficit, kPa
C        LAI     projected leaf area index
C        SAI     projected stem area index
C        R5      solar radiation at which conductance is halved, W/m2
C        CVPD    vpd at which conductance is halved, kPa
C        RM      maximum solar radiation, at which FR = 1,  W/m2
C        CR      light extinction coefficient for projected LAI
C        GLMAX   maximum leaf surface conductance for all sides of leaf, m/s
C        GLMIN   cuticular leaf surface conductance for all sides of leaf, m/s
C     local
C        FS      correction for stem area
C        R0      a light response parameter
C        FRINT   integral of fR dL over Lp
C        FD      dependence of leaf conductance on vpd, 0 to 1
C        FT      dependence of leaf conductance on temperature, 0 to 1
C        GSC     canopy conductance, m/s
      IMPLICIT NONE
      REAL RAD, TMIN, DD, LAI, SAI, R5, CVPD, RM, CR, GLMAX,
     *   GLMIN, FS, R0, FRINT, FD, FT, GSC
      REAL MAX, EXP, LOG
C      INTRINSIC MAX, EXP, LOG - FBM SGI did not like
C

C     solar radiation limitation integrated down through canopy
C     Stewart (1988) and Saugier and Katerji (1991)
      FS = (LAI + SAI) / LAI
      IF (RAD .LE. 1E-10) THEN
         FRINT = 0
      ELSE
         R0 = RM * R5 / (RM - 2 * R5)
         FRINT = ((RM + R0) / (RM * CR * FS)) *
     *           LOG((R0 + CR * RAD) /
     *               (R0 + CR * RAD * EXP(-CR * FS * LAI)))
      END IF
C     vapor deficit limitation
C     Lohammar et al. (1980) and Stannard (1993)
      FD = 1 / (1 + DD / CVPD)
C     temperature limitation
C     limitation only by low minimum daily temperature (TMIN)
      IF (TMIN .GT. 0.) THEN
         FT = 1
      ELSEIF (TMIN .LT. -5.) THEN
         FT = 0.
      ELSE
         FT = 1. + TMIN / 5.
      END IF

      GSC = FD * FT * FRINT * (GLMAX - GLMIN) + LAI * GLMIN
C        not less than cuticular conductance
      SRSCF = 1 / GSC

      END
