C#######################################################################
C#                                                                    ##
C#               PPPP   W           W  BBBBBB   M       M             ##
C#               P   P   W         W   B    B   MM     MM             ##
C#               PPPP     W   W   W    BBBBBB   M M   M M             ##
C#               P         W W W W     B    B   M  M M  M             ##
C#               P          W   W      BBBBBB   M   M   M             ##
C#                                                                    ##
C#                                                                    ##
C#                    PERMAFROST WATER BALANCE MODEL                  ##
C#                     +++++   Version 4.0   +++++                    ##
C# . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .##
C#                                                                    ##
C#                 PWBM VERSION 4.0 CAN BE OBTAINED AT:               ##
C#                                                                    ##
C#                  https://blogs.umass.edu/csrc/pwbm                 ##
C#                                                                    ##
C# . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .##
C#                                                                    ##
C#              *****  PWBM (v4) subroutine: waterzone *****          ##
C#    Subroutine handles water balance of inundated areas             ##
C#                                                                    ##
C#                                                                    ##
C#     NOTE:   See notes in PWBM main routine, file pwbmModel_v4.f    ##
C#                                                                    ##
c***********************************************************************      

      subroutine waterzone(tempAir,precipRain,precipSnow,snow_melt_land,
     $ wetlandwatprev,
     $ wetlandsnowprev,pet,wetlandwat,wetlandsnow,extent_Min,extent_Max,
     $ wetlandrunoff,wetlandevap,iwrite)
c
c  Subroutine to determine disposition of water in lake or other wetland.
c  ET occurs at the potential rate. Need to look closer at runoff, calculated
c  by P-E. I've set to always be positive. How does that affect water amount?
c
c  iwrite is a flag that can be used to write some variables if desired.
c
c  INPUTS:
c
c  tempAir [C]  
c  precipRain [mm/day] - precipitation as rain for the current day
c  precipSnow [mm/day] - precipitation as snow for the current day
c  snow_melt_land [mm /day] - snow melt computed in land routine
c  wetlandprev [mm] - unit depth of the lake or wetland on previous day
c  pet [mm/day] - potential evapotranspiration for the current day
c  
c  OUTPUTS:
c
c  wetlandwat [mm] - unit depth of the lake or wetland
c  wetlandrunoff [mm/day] - runoff (discharge) from the lake or wetland on day
c  wetlandevap [mm/day] - evaporation from lake or wetland on current day
c
      implicit none
      integer ii,iflag,iwrite
      real*8 tempAir,precipRain,precipSnow,wetlandsnowprev,wetlandsnow
      real*8 availwat,wetlandwatprev,pet,wetlandwat,wetlandrunoff
      real*8 balance,water_in,water_out,check,netP,diff,wetlandevap
      real*8 extent_Min,extent_Max,wet_prevextent,wet_newextent
      real*8 widthfraction,depthareafunc,depthMin,depthMax,depthprev
      real*8 frac,depth,depth_frac4range,meltwat,snow_melt_land
      real*8 sublimation

      widthfraction = 0.25d0
      depthMax = 50.0d0     
      depthMin = 6.0d0      
      extent_Max = 0.8d0    

      availwat = precipRain + precipSnow
      water_in = (wetlandwatprev + wetlandsnowprev) + availwat

      depth_frac4range = (depthprev - depthMin) / (depthMax - depthMin)
      
c  Add any precipitation to the water and snow storages
      wetlandsnow = wetlandsnowprev + precipSnow
      wetlandwat = wetlandwatprev + precipRain

c  Melt from snowpack
      if (tempAir .gt. 0.0d0) then
         meltwat = min(snow_melt_land,wetlandsnow)
         if (meltwat .lt. wetlandsnow*0.25d0) meltwat=wetlandsnow*0.25d0
         wetlandsnow = wetlandsnow - meltwat
         wetlandwat = wetlandwat + meltwat
      endif

c  Evaporation for the water body.   
      if (wetlandsnow .gt. 0.0d0) then
         diff = wetlandsnow - pet    
         if (diff .ge. 0.0d0) then
            sublimation = pet  
            wetlandsnow = wetlandsnow - pet
         else
            sublimation = wetlandsnow   
            wetlandsnow = 0.0d0
            pet = pet - sublimation    
         endif
      endif   

      diff = wetlandwat - 10.0d0 
      if (tempAir .gt. 0.0d0) then
         if (wetlandwat .ge. pet) then
            wetlandevap = dmin1(pet,diff)  
            wetlandwat = wetlandwat - wetlandevap
         else
            wetlandevap = diff
            wetlandwat = 10.0d0
         endif
      else
         wetlandevap = 0.0d0
      endif
   
c  Create some runoff. Then subtract runoff from the wetland amount. 

      if (wetlandwat .gt. 10.0d0 .and. tempAir .gt. 0.0d0) then
         diff = wetlandwat - 10.0d0
         frac = diff * 0.10d0
         wetlandrunoff = frac
         wetlandwat = wetlandwat - frac
      else
         wetlandrunoff = 0.0d0
      endif   
      
c  Perform water balance check
      wetlandevap = wetlandevap + sublimation
      water_out = wetlandwat + wetlandsnow + wetlandevap + wetlandrunoff
      check = water_in - water_out
      if (abs(check) .gt. 1.0d-6) then
         print*, 'water balance error in lake/wetland routine'
         write(*,*) 'Total input water = ', water_in
         write(*,*) 'Total output water = ', water_out
         write(*,*) 'Previous days lake/wetland water = ',wetlandwatprev
         write(*,*) 'Water to surface = ', availwat
         write(*,*) 'Wetland water = ', wetlandwat
         write(*,*) 'Lake/wetland tot evaporation = ', wetlandevap
         write(*,*) 'Runoff = ', wetlandrunoff
         write(*,*) 'Check = ', check
         stop
      endif

      return
      end
