C#######################################################################
C#                                                                    ##
C#               PPPP   W           W  BBBBBB   M       M             ##
C#               P   P   W         W   B    B   MM     MM             ##
C#               PPPP     W   W   W    BBBBBB   M M   M M             ##
C#               P         W W W W     B    B   M  M M  M             ##
C#               P          W   W      BBBBBB   M   M   M             ##
C#                                                                    ##
C#                                                                    ##
C#                    PERMAFROST WATER BALANCE MODEL                  ##
C#                     +++++   Version 4.0   +++++                    ##
C# . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .##
C#                                                                    ##
C#                 PWBM VERSION 4.0 CAN BE OBTAINED AT:               ##
C#                                                                    ##
C#                  https://blogs.umass.edu/csrc/pwbm                 ##
C#                                                                    ##
C# . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .##
C#                                                                    ##
C#              *****  PWBM (v4) subroutine: surface_snow  *****      ##
C#    Subroutine handles snow density and conductivity                ##
C#     following Sturm et al., 1997 and Liston et al., 2007           ##
C#                                                                    ##
C#     NOTE:   See notes in PWBM main routine, file pwbmModel_v4.f    ##
C#                                                                    ##
c***********************************************************************
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c  Change from Liston method: setting min new snow density to 125 g/cm3

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine surface_snow_1(Tair,windspd,prec,ro_soft_snow_old,
     &    Utau_t,ro_soft_snow,snowconduct,snowheatcapacity)

      implicit none
      real*8 C,alfa,ro_min,ro_max,prec,Tair,Tobs_K,ro_nsnow,dt,Tf,
     &  ro_offset,windspd,Utau_t,ro_soft_snow_old,ro_soft_snow,
     &  windspd_2m,snow_z0,ht_windobs,snowconduct,snowheatcapacity


c Define the density rate coefficients. It is a non-dimensional constant
c  that controls the simulated snow density change rate.
      C = 0.10d0

c Define alfa. 
      alfa = 0.2d0

c Define the minimum and maximum snow density that should be simulated.
      ro_min = 75.0d0
      ro_max = 450.0d0

c Freezing temperature.
      Tf = 273.16d0

c Snow surface roughness length.
      snow_z0 = 0.001d0

c Height of wind obs. I'm assuming 2 meters.
      ht_windobs = 2.0d0

c dTime is seconds per day.
      dt = 86400.0d0

c Calculate the 2-m wind speed. Note: I probably will ASSUME wind obs are 2m.
      windspd_2m = windspd *
     &     log(2.0d0/snow_z0) / log(ht_windobs/snow_z0)

c Convert observed air temperature from degrees C to Kelvin.
      Tobs_K = tair + Tf

c Calculate the new snow density.  First calculate this under the
c   assumption of no wind using the standard SnowModel formulation,
c   then calculate the offset for wind speeds > 5 m/s.
      if (prec .gt. 0.0d0) then

c  Find new snow layer density, as a function of air temperature. Only
c   two different values here. Use four like in Liston paper (see Fig 4)
c  Twb is wet bulb temperature (K). I'm using daily gridded air temperature.
ccccccccccccccccc   ro_min used here is set above  cccccccccccccccc
      if (Tobs_K .ge. 258.16d0) then
        ro_nsnow = ro_min + 1.7d0 * (Tobs_K - 258.16d0)**1.5
c       print*, Tobs_K, Tobs_K - 258.16, (Tobs_K - 258.16)**1.5
      else
        ro_nsnow = ro_min
      endif  

c To define the offset I assumed under cold conditions (ro_nsnow =
c   50.0 kg/m3):
c   1) 24-hour ave wind speed >= 20 m/s gives ro_nsnow = 350 kg/m3.
c   2) 24-hour ave wind speed = 5 m/s gives ro_nsnow = 150 kg/m3,
c      (actually what really matters here is the density difference
c      of 200 kg/m3 for the wind speed difference from 5 to 20 m/s).
c   3) 24-hour ave wind speed < 5 m/s gives ro_nsnow = ro_nsnow.
c   4) It is appropriate to use an exponential decay function
c      between the 5 and 20 m/s values.

        if (windspd_2m .lt. 5.0d0) then
          ro_offset = 0.0d0       ! offset not applied
        else
          ro_offset = 25.0d0 +    ! wind-related density offset
     &      250.0d0 * (1.0d0 - exp(-(alfa*(windspd_2m - 5.0d0))))
        endif

!  Adjust density of (input) new snow with the wind offset.
        ro_soft_snow = ro_nsnow + ro_offset
        ro_soft_snow = min(ro_soft_snow,ro_max)
        ro_soft_snow = max(ro_soft_snow,ro_min)
c        write(99,*) windspd_2m, ro_nsnow, ro_offset, ro_soft_snow

        if (ro_soft_snow .le. 300.0d0) then
          Utau_t = 0.10d0 * exp(0.003d0 * ro_soft_snow)
        else
          Utau_t = 0.005d0 * exp(0.013d0 * ro_soft_snow)
        endif
      else
        call surface_snow_2(ro_soft_snow_old,dt,Tobs_K,
     &   windspd_2m,C,ro_max,ro_min,alfa,Tf,ro_soft_snow,Utau_t)
        ro_soft_snow_old = ro_soft_snow
      endif
      snowconduct = 10.0D0 **   ! eq 7, Sturm et al. JG 1997
     $      (2.65D0 * (ro_soft_snow/1.0D3) - 1.652D0)
      snowheatcapacity = 2.05114D3 * ro_soft_snow * 1.0e-6 ! units (J m3 K-1)

      return
      end

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

      subroutine surface_snow_2(ro_soft_snow_old,dt,Tobs_K,
     &  windspd_2m,C,ro_max,ro_min,alfa,Tf,ro_soft_snow,Utau_t)

      implicit none

      real*8 Tf,Tsnow,Tobs_K,ro_soft_snow,dt,A1,A2,B,U,C,
     &  windspd_2m,Utau_t,ro_soft_snow_old,ro_max,ro_min,alfa

      A1 = 0.0013d0
      A2 = 0.021d0
      B = 0.08d0
      C = 0.01d0

c Evolve the near-surface snow density under the influence of
c   temperature and snow-transporting wind speeds.

c Assume that the near-surface snow temperature equals the air
c   temperature, but is not above the melting point.
      Tsnow = min(Tf,Tobs_K)

c Update the snow density of the soft snow layer with a wind-speed 
c   contribution, U. Eliminate the wind speed influence for speeds below 5 m/s, 
c   but account for it if >= 5 m/s.  U is eq. 18 in Liston et al., 2007
      if (windspd_2m .ge. 5.0d0) then
        U = 5.0d0 + 15.0d0 * (1.0d0 - exp(-(alfa*(windspd_2m - 5.0d0))))
      else
        U = 1.0d0
      endif

c The temporal change in snow density (eq. 17 in Liston et al., 2007):
      ro_soft_snow = ro_soft_snow_old + dt *
     &  (C * A1 * U * ro_soft_snow_old *
     &  exp((-B)*(Tf-Tsnow)) * exp((-A2)*ro_soft_snow_old))
c      write(*,*) 'No prcp: ',  ro_soft_snow
c      write(90,*) Tf, Tsnow, ro_soft_snow_old, dt, U, C * A1 * U, 
c     $       exp((-B)*(Tf-Tsnow)), exp((-A2)*ro_soft_snow_old)
c      write(99,*) 'X ', windspd_2m, ro_soft_snow_old, ro_soft_snow

c Bound the calculated density.
      ro_soft_snow = min(ro_max,ro_soft_snow)
      ro_soft_snow = max(ro_min,ro_soft_snow)

c Calculate the snow threshold friction velocity.
      if (ro_soft_snow .le. 300.0d0) then
        Utau_t = 0.10d0 * exp(0.003d0 * ro_soft_snow)
c        write(90,*) 'X ', ro_soft_snow, Utau_t
      else
        Utau_t = 0.005d0 * exp(0.013d0 * ro_soft_snow)
c        write(90,*) 'XX ', ro_soft_snow, Utau_t
      endif

      return
      end

